



if not exist %LIBRARY_BIN%\\abseil_dll.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_LIB%\\abseil_dll.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_BIN%\\abseil_test_dll.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\abseil_test_dll.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_LIB%\\absl_log_flags.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_log_flags
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_LIB%\\absl_flags_commandlineflag.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_flags_commandlineflag
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_LIB%\\absl_flags_config.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_flags_config
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_LIB%\\absl_flags_marshalling.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_flags_marshalling
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_LIB%\\absl_flags_parse.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_flags_parse
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_LIB%\\absl_flags_private_handle_accessor.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_flags_private_handle_accessor
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_LIB%\\absl_flags_program_name.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_flags_program_name
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_LIB%\\absl_flags_reflection.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_flags_reflection
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_LIB%\\absl_flags_usage.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_flags_usage
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_base.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_base
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_civil_time.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_civil_time
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_cord.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_cord
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_cordz_functions.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_cordz_functions
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_cordz_handle.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_cordz_handle
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_cordz_info.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_cordz_info
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_cordz_sample_token.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_cordz_sample_token
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_examine_stack.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_examine_stack
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_exponential_biased.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_exponential_biased
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_failure_signal_handler.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_failure_signal_handler
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_hash.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_hash
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_hashtablez_sampler.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_hashtablez_sampler
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_int128.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_int128
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_log_severity.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_log_severity
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_low_level_hash.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_low_level_hash
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_periodic_sampler.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_periodic_sampler
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_random_distributions.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_random_distributions
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_random_seed_gen_exception.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_random_seed_gen_exception
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_random_seed_sequences.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_random_seed_sequences
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_raw_hash_set.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_raw_hash_set
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_scoped_set_env.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_scoped_set_env
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_spinlock_wait.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_spinlock_wait
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_stacktrace.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_stacktrace
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_status.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_status
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_statusor.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_statusor
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_strerror.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_strerror
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_strings.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_strings
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_symbolize.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_symbolize
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_synchronization.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_synchronization
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_time.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_time
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_time_zone.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" absl_time_zone
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist %LIBRARY_LIB%\\absl_scoped_mock_log.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
pkg-config --print-errors --exact-version "20240116" abseil_dll
IF %ERRORLEVEL% NEQ 0 exit /B 1
cd cmake_test
IF %ERRORLEVEL% NEQ 0 exit /B 1
set "CMAKE_ARGS=%CMAKE_ARGS% -GNinja -DCMAKE_BUILD_TYPE=Release"
IF %ERRORLEVEL% NEQ 0 exit /B 1
cmake %CMAKE_ARGS% -DCMAKE_CXX_STANDARD=17 .
IF %ERRORLEVEL% NEQ 0 exit /B 1
cmake --build .
IF %ERRORLEVEL% NEQ 0 exit /B 1
flags_example.exe
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
